==> hudi-1.0.1.src.tgz: hudi-1.0.1/hudi-common/src/main/java/org/apache/hudi/common/util/collection/FilterIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.common.util.collection;

import org.apache.hudi.common.util.ValidationUtils;

import java.util.Iterator;
import java.util.function.Predicate;

/**
 * An iterator that filters elements from a source iterator based on a predicate.
 * @param <R> Type of elements in the iterator
 */
public class FilterIterator<R> implements Iterator<R> {

  private final Iterator<R> source;

  private final Predicate<R> filter;

  private R current;

  public FilterIterator(Iterator<R> source, Predicate<R> filter) {
    this.source = source;
    this.filter = filter;
  }

  @Override
  public boolean hasNext() {
    while (current == null && source.hasNext()) {
      R next = source.next();
      if (filter.test(next)) {
        current = next;
        break;
      }
    }
    return current != null;
  }

  @Override
  public R next() {
    ValidationUtils.checkArgument(hasNext(), "No more elements to iterate");
    R next = current;
    current = null;
    return next;
  }
}

==> hudi-1.1.1.src.tgz: hudi-1.1.1/hudi-common/src/main/java/org/apache/hudi/common/util/collection/FilterIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.common.util.collection;

import org.apache.hudi.common.util.ValidationUtils;

import java.util.Iterator;
import java.util.function.Predicate;

/**
 * An iterator that filters elements from a source iterator based on a predicate.
 * @param <R> Type of elements in the iterator
 */
public class FilterIterator<R> implements Iterator<R> {

  protected final Iterator<R> source;

  private final Predicate<R> filter;

  private R current;

  public FilterIterator(Iterator<R> source, Predicate<R> filter) {
    this.source = source;
    this.filter = filter;
  }

  @Override
  public boolean hasNext() {
    while (current == null && source.hasNext()) {
      R next = source.next();
      if (filter.test(next)) {
        current = next;
        break;
      }
    }
    return current != null;
  }

  @Override
  public R next() {
    ValidationUtils.checkArgument(hasNext(), "No more elements to iterate");
    R next = current;
    current = null;
    return next;
  }
}
